Bioregistry |release| Documentation
===================================
.. toctree::
   :maxdepth: 2
   :caption: Getting Started
   :name: start

   installation
   cli

Indices and Tables
------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
